﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using ColumnChart.Resources;
using System.ComponentModel;
using System.Collections.ObjectModel;
using Syncfusion.UI.Xaml.Charts;
using System.Windows.Input;
using System.Windows.Media;

namespace ColumnChart
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Sample code to localize the ApplicationBar
            //BuildLocalizedApplicationBar();
        }

        // Sample code for building a localized ApplicationBar
        //private void BuildLocalizedApplicationBar()
        //{
        //    // Set the page's ApplicationBar to a new instance of ApplicationBar.
        //    ApplicationBar = new ApplicationBar();

        //    // Create a new button and set the text value to the localized string from AppResources.
        //    ApplicationBarIconButton appBarButton = new ApplicationBarIconButton(new Uri("/Assets/AppBar/appbar.add.rest.png", UriKind.Relative));
        //    appBarButton.Text = AppResources.AppBarButtonText;
        //    ApplicationBar.Buttons.Add(appBarButton);

        //    // Create a new menu item with the localized string from AppResources.
        //    ApplicationBarMenuItem appBarMenuItem = new ApplicationBarMenuItem(AppResources.AppBarMenuItemText);
        //    ApplicationBar.MenuItems.Add(appBarMenuItem);
        //}
    }
    public class ChartSelectionBehaviors : ChartSelectionBehavior
    {
        public ChartSelectionBehaviors()
        {

        }
        ChartSegment segment;
        Brush brush;
        ObservableCollection<ChartSegment> segments;

        protected override void OnLayoutUpdated()
        {
            var series = ChartArea.Series[0] as CustomSelectableSeries;
            if (series != null)
            {
                segments = series.PublicSegments;
                if (segments != null)
                {
                    segment = segments[series.SegmentSelectedIndex];
                    brush = segment.Interior;
                    OnSelectionChanged(segment);
                }
            }
            base.OnLayoutUpdated();
        }

        protected override void OnSizeChanged(SizeChangedEventArgs e)
        {
            base.OnSizeChanged(e);

        }

        protected override void OnMouseMove(MouseEventArgs e)
        {
            base.OnMouseMove(e);
        }

        protected override void OnMouseLeftButtonUp(MouseButtonEventArgs e)
        {
            if (segment != null)
            {
                segment.Interior = brush;
                segment = null;
            }
            base.OnMouseLeftButtonUp(e);
        }

        protected override void OnSelectionChanged(ChartSegment segment)
        {
            if (segment == null) return;
            var customSeries = segment.Series as CustomSelectableSeries;
            if (segments != null && customSeries != null)
            {
                customSeries.SegmentSelectedIndex = segments.IndexOf(segment);
            }
            base.OnSelectionChanged(segment);
        }
    }
    public class CustomSelectableSeries : ColumnSeries
    {
        public ObservableCollection<ChartSegment> PublicSegments;


        public int SegmentSelectedIndex
        {
            get { return (int)GetValue(SegmentSelectedIndexProperty); }
            set { SetValue(SegmentSelectedIndexProperty, value); }
        }

        // Using a DependencyProperty as the backing store for SegmentSelectedIndex.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty SegmentSelectedIndexProperty =
            DependencyProperty.Register("SegmentSelectedIndex", typeof(int), typeof(CustomSelectableSeries), new PropertyMetadata(0));

        public override void CreateSegments()
        {
            base.CreateSegments();
            PublicSegments = Segments;
        }
    }

    public class CategoryDataViewModel
    {
        public CategoryDataViewModel()
        {
            CategoricalDatas = new ObservableCollection<CategoryData>();
            CategoricalDatas.Add(new CategoryData("Metal", 5));
            CategoricalDatas.Add(new CategoryData("Plastic", 10));
            CategoricalDatas.Add(new CategoryData("Silver", 15));
            CategoricalDatas.Add(new CategoryData("Iron", 20));
        }
        public ObservableCollection<CategoryData> CategoricalDatas
        {
            get;
            set;
        }
    }

    public class CategoryData : INotifyPropertyChanged
    {
        private string category; private double value;

        public CategoryData(string category, double value)
        {
            Category = category; Value = value;
        }

        public string Category
        {
            get
            { return category; }
            set
            {
                if (category != value)
                {
                    category = value;
                    OnPropertyChanged("Category");
                }
            }
        }

        public double Value
        {
            get
            { return value; }
            set
            {
                if (this.value != value)
                {
                    this.value = value;
                    OnPropertyChanged("Value");
                }
            }
        }


        void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        public event PropertyChangedEventHandler PropertyChanged;
    }
}